from lazyTest.file import IniFileOperation,Csv_File_Operation
from lazyTest.utils import Sleep, readElementSource,writeElementKey, ClearTestResult, createData,cls_Sleep
from lazyTest.case import TestCase
from lazyTest.base import  browser_Config
from lazyTest.page import Page

__version__ = '1.1.6'

__author__ = 'buxiubuzhi'

__description__ = "WebUI自动化测试框架"

__all__ = [
    "Sleep",
    "Page",
    "readElementSource",
    "writeElementKey",
    "ClearTestResult",
    "browser_Config",
    "createData",
    "IniFileOperation",
    "TestCase",
    "cls_Sleep",
    "Csv_File_Operation"
]
